Learn R Programming

sspline (version 0.1-6)

WT6367: World Average Winter Temperature from 1963-1967

Description

The WT6367 data frame has 1391 rows and 4 columns. It contains the average temperature from 1963 to 1967 for those stations having non-missing observations on the winter (Dec-Feb) for ten years (1963-1967 and 1993-1997).

Usage

WT6367

Arguments

Format

This data frame contains the following columns:
recid
a numeric vector containing the coded information of the stations (length 11). The first three digits represent the country code; the next five digits, the station number; the last three digits, whether a station is a WMO staion or close to one.
lon
a numeric vector containing the longitudes (in degrees) of the stations.
lat
a numeric vector containing the latitudes (in degrees) of the stations.
avgt
a numeric vector containing the average temperatures for the stations (rounded to the second decimal point).

The Global Historical Climatology Network (GHCN) http://www.ncdc.noaa.gov/cgi-bin/res40.pl?page=ghcn.html

Examples

Run this code
## Fit a smoothing spherical spline with part of the data
subdat <- WT6367[sample(nrow(WT6367), 200), 2:4]
attach(subdat)

smooth.sspline(lon, lat, avgt)

detach(subdat)

Run the code above in your browser using DataLab