WT9397: World Average Winter Temperature from 1993-1997
Description
The WT9397 data frame has 1391 rows and 4 columns.
It contains the average temperature from 1993 to 1997 for
those stations having non-missing observations on the
winter (Dec-Feb) for ten years (1963-1967 and 1993-1997).
Usage
WT9397
Arguments
Format
This data frame contains the following columns:
recid
a numeric vector containing the coded information of the
stations (length 11). The first three digits represent the
country code; the next five digits, the station number; the
last three digits, whether a station is a WMO staion or close
to one.
lon
a numeric vector containing the longitudes (in degrees) of
the stations.
lat
a numeric vector containing the latitudes (in degrees) of
the stations.
avgt
a numeric vector containing the average temperatures for
the stations (rounded to the second decimal point).
## Fit a smoothing spherical spline with part of the datasubdat <- WT9397[sample(nrow(WT9397), 200), 2:4]
attach(subdat)
smooth.sspline(lon, lat, avgt)
detach(subdat)