Learn R Programming

sspline (version 0.1-3)

predict.smooth.sspline: Spherical Smoothing Spline Prediction

Description

Make prediction on the sphere using the information got from a smooth.sspline object.

Usage

predict.smooth.sspline(object, lon, lat, grid=FALSE, ...)

Arguments

object
a smooth.sspline object
lon
the longitudes on which the prediction is to be made
lat
the latitudes on which the prediction is to be made
grid
whether the prediction is on a grid
...
other parameters, not used

Value

  • If grid = TRUE, return a matrix with dimension (length(lon), length(lat)); otherwise, return a vector of length = length(lon).

Details

It calls Fortran subroutine with the .Fortran interface.

References

Grace Wahba (1981), Spline Interpolation and Smoothing on the Sphere, SIAM J. SCI. STAT. COMPUT.

See Also

smooth.sspline

Examples

Run this code
data(WT9397)

subdat <- WT9397[sample(nrow(WT9397), 200), 2:4]
attach(subdat)

splobj <- smooth.sspline(lon, lat, avgt)

predict(splobj, lon=seq(-180,180,len=50), lat=seq(-90,90,len=25), grid=TRUE)

detach(subdat)

Run the code above in your browser using DataLab