Learn R Programming

sspline (version 0.1-3)

station: Distribution of the Stations on the World

Description

It gives a simple illumination on how the given (lon, lat) pairs distributes on the world.

Usage

station(lon=NULL, lat=NULL, pch=24, col="blue", bg="red", ...)

Arguments

lon
numeric, the longitudes
lat
numeric, the latitudes
pch
the plotting symbol
col
color value or name, the color used to draw the symbol
bg
color value or name, the color used to fill the sumbol
...
other plotting parameters

Value

  • NULL

Details

It calls the map.world to draw a world map.

See Also

map.world

Examples

Run this code
data(WTdiff)
subdat <- WTdiff[sample(nrow(WTdiff), 200), 2:3]
attach(subdat)

station(lon, lat)

detach(subdat)

Run the code above in your browser using DataLab